# Ramo
Ramo is an algorithmic game theory framework offering a collection of algorithms and utilities for computing or learning (approximate) equilibria in multi-objective games.

Please visit [Ramo's docs](https://ramo.readthedocs.io/en/latest/) for a complete overview of the framework and its capabilities.

## Installation
Installing Ramo is as easy as typing
````python
pip install ramo
````

If you would like to install from source, simply download this project as a zip file and place the folder at your desired location.

## Contributing
We are building a library containing cutting edge research in multi-objective game theory. If you are working in this area and want to get involved, contributions are very welcome! Our focus is specifically on multi-objective games, but single-objective contributions are also welcome. If you are considering contributing, please send me a message (willem.ropke@vub.be) so we can discuss how to move forward.

## Citation
To cite the usage of this repository please use the following:
```
@misc{ropke2022ramo,
  author = {Willem Röpke},
  title = {Ramo: Rational Agents with Multiple Objectives},
  year = {2022},
  publisher = {GitHub},
  journal = {GitHub repository},
  howpublished = {\url{https://github.com/wilrop/mo-game-theory}},
}
```
This repository contains (derivatives of) original work that has been published elsewhere. We present a complete overview of which algorithms come from which work in [references.md](references.md).

## License
This project is licensed under the terms of the MIT license.

